@@ -70,7 +70,7 @@ class JsonSchema(Directive):
         return self.schema.get("required", [])
 
     @cached_property
-    def content(self) -> List[nodes.section]:
+    def jsonschema_content(self) -> List[nodes.section]:
         return []
 
     def handle_property(self, title, prop) -> None:
@@ -99,7 +99,7 @@ class JsonSchema(Directive):
             for text_node in default_text:
                 default += text_node
             section += default
-        self.content.append(section)
+        self.jsonschema_content.append(section)
 
     def run(self):
         if self.schema is None:
@@ -108,4 +108,4 @@ class JsonSchema(Directive):
         sorted_props = {k: properties[k] for k in sorted(properties)}
         for title, prop in sorted_props.items():
             self.handle_property(title, prop)
-        return self.content
+        return self.jsonschema_content
